Full-text search across PDF documents.
Provides search functionality using extracted text and positioned characters.
Structs
- Search
Options - Options for text search.
- Search
Result - A search result with location information.
Functions
- count_
occurrences - Count the total number of occurrences of a query across all pages.
- count_
text_ only - Fast text-only occurrence count — skips all bounding box extraction.
- pages_
containing - Return a list of page numbers that contain the query text.
- search_
text - Search for text across all pages of a document.